import sys
import typing

GenericType = typing.TypeVar("GenericType")


def activate(template_id, reload_scripts):
    ''' 

    '''

    ...


def import_from_id(template_id, ignore_not_found):
    ''' 

    '''

    ...


def import_from_path(path, ignore_not_found):
    ''' 

    '''

    ...


def reset(reload_scripts):
    ''' 

    '''

    ...
