import sys
import typing

GenericType = typing.TypeVar("GenericType")


def complete(line):
    ''' 

    '''

    ...


def get_root_modules():
    ''' 

    '''

    ...


def module_list(path):
    ''' 

    '''

    ...
