import sys
import typing

GenericType = typing.TypeVar("GenericType")


class _TempModuleOverride:
    module: typing.Any
    ''' '''

    module_name: typing.Any
    ''' '''

    module_override: typing.Any
    ''' '''


def add_scrollback(text, text_type):
    ''' 

    '''

    ...


def autocomplete(context):
    ''' 

    '''

    ...


def banner(context):
    ''' 

    '''

    ...


def copy_as_script(context):
    ''' 

    '''

    ...


def execute(context, is_interactive):
    ''' 

    '''

    ...


def get_console(console_id):
    ''' 

    '''

    ...


def replace_help(namespace):
    ''' 

    '''

    ...
