import sys
import typing

GenericType = typing.TypeVar("GenericType")


def cleanup_po(args, settings):
    ''' 

    '''

    ...


def language_menu(args, settings):
    ''' 

    '''

    ...


def main():
    ''' 

    '''

    ...


def rtl_process_po(args, settings):
    ''' 

    '''

    ...


def strip_po(args, settings):
    ''' 

    '''

    ...


def update_po(args, settings):
    ''' 

    '''

    ...
